@@ -6,7 +6,7 @@ use Storable; # RT117983
 use Class::Autouse qw{Carp Locale::Language Locale::Object::Country Locale::Object::DB I18N::AcceptLanguage I18N::LangTags::Detect};
 
 use vars qw($VERSION);
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 
 =head1 NAME
 
@@ -14,7 +14,7 @@ CGI::Lingua - Create a multilingual web page
 
 =head1 VERSION
 
-Version 0.57
+Version 0.58
 
 =cut
 
@@ -191,12 +191,13 @@ sub DESTROY {
 	my $copy = bless {
 		_slanguage => $self->{_slanguage},
 		_slanguage_code_alpha2 => $self->{_slanguage_code_alpha2},
+		_sublanguage_code_alpha2 => $self->{_sublanguage_code_alpha2},
 		_country => $self->{_country},
 		_rlanguage => $self->{_rlanguage},
 		_dont_use_ip => $self->{_dont_use_ip},
 		_have_ipcountry => $self->{_have_ipcountry},
 		_have_geoip => $self->{_have_geoip},
-		_have_geoipfree => $self->{_have_geoipfree}
+		_have_geoipfree => $self->{_have_geoipfree},
 	}, ref($self);
 
 	# All of these crash, presumably something recursive is going on
@@ -744,20 +745,31 @@ sub _get_closest {
 sub _what_language {
 	my $self = shift;
 
-	if(ref($self) && (my $info = $self->{_info})) {
-		if(my $rc = $info->lang()) {
-			# E.g. cgi-bin/script.cgi?lang=de
-			return $rc;
+	if(ref($self)) {
+		if($self->{_what_language}) {
+			return $self->{_what_language};	# Useful in case something changes the $info hash
+		}
+		if(my $info = $self->{_info}) {
+			if(my $rc = $info->lang()) {
+				# E.g. cgi-bin/script.cgi?lang=de
+				return $self->{_what_language} = $rc;
+			}
 		}
 	}
 
 	if(defined($ENV{'LANG'})) {
 		# Running the script locally, presumably to debug, so set the language
 		# from the Locale
+		if(ref($self)) {
+			return $self->{_what_language} = $ENV{'LANG'};
+		}
 		return $ENV{'LANG'};
 	}
 
 	if($ENV{'HTTP_ACCEPT_LANGUAGE'}) {
+		if(ref($self)) {
+			return $self->{_what_language} = $ENV{'HTTP_ACCEPT_LANGUAGE'};
+		}
 		return $ENV{'HTTP_ACCEPT_LANGUAGE'};
 	}
 }
